==> knative-model-4.9.2-sources.jar: annotations/io/fabric8/knative/flows/v1alpha1/SequenceSubscriptionStatusFluent.java <==
package io.fabric8.knative.flows.v1alpha1;

import io.fabric8.knative.v1.Condition;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.knative.v1.ConditionFluent;
import io.fabric8.knative.v1.ConditionBuilder;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface SequenceSubscriptionStatusFluent<A extends SequenceSubscriptionStatusFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildReady instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public Condition getReady();
    public Condition buildReady();
    public A withReady(Condition ready);
    public Boolean hasReady();
    public SequenceSubscriptionStatusFluent.ReadyNested<A> withNewReady();
    public SequenceSubscriptionStatusFluent.ReadyNested<A> withNewReadyLike(Condition item);
    public SequenceSubscriptionStatusFluent.ReadyNested<A> editReady();
    public SequenceSubscriptionStatusFluent.ReadyNested<A> editOrNewReady();
    public SequenceSubscriptionStatusFluent.ReadyNested<A> editOrNewReadyLike(Condition item);
    public ObjectReference getSubscription();
    public A withSubscription(ObjectReference subscription);
    public Boolean hasSubscription();

    public interface ReadyNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ConditionFluent<SequenceSubscriptionStatusFluent.ReadyNested<N>>{

        
    public N and();    public N endReady();
}


}

==> knative-model-4.11.0-sources.jar: annotations/io/fabric8/knative/flows/v1alpha1/SequenceSubscriptionStatusFluent.java <==
package io.fabric8.knative.flows.v1alpha1;

import io.fabric8.knative.internal.pkg.apis.Condition;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.knative.internal.pkg.apis.ConditionFluent;
import io.fabric8.knative.internal.pkg.apis.ConditionBuilder;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface SequenceSubscriptionStatusFluent<A extends SequenceSubscriptionStatusFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildReady instead.
 * @return The buildable object.
 */
@Deprecated public Condition getReady();
    public Condition buildReady();
    public A withReady(Condition ready);
    public Boolean hasReady();
    public SequenceSubscriptionStatusFluent.ReadyNested<A> withNewReady();
    public SequenceSubscriptionStatusFluent.ReadyNested<A> withNewReadyLike(Condition item);
    public SequenceSubscriptionStatusFluent.ReadyNested<A> editReady();
    public SequenceSubscriptionStatusFluent.ReadyNested<A> editOrNewReady();
    public SequenceSubscriptionStatusFluent.ReadyNested<A> editOrNewReadyLike(Condition item);
    public ObjectReference getSubscription();
    public A withSubscription(ObjectReference subscription);
    public Boolean hasSubscription();

    public interface ReadyNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ConditionFluent<SequenceSubscriptionStatusFluent.ReadyNested<N>>{

        
    public N and();    public N endReady();
}


}
